# coding=utf-8
# 利用获取的cookies，完成模拟登录淘宝网（cookies如果过期了，需要重新用Taobao1获取下cookies） 2021-04-16
from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from sampleSprider.Common.Info import Paypal
from selenium.webdriver.common.action_chains import ActionChains

headers = {
    'authority': 'gma.alicdn.com',
    'cache-control': 'no-cache',
    'sec-ch-ua': '"Google Chrome";v="89", "Chromium";v="89", ";Not A Brand";v="99"',
    'sec-ch-ua-mobile': '?0',
    'upgrade-insecure-requests': '1',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36',
    'accept': 'image/avif,image/webp,image/apng,image/svg+xml,image/*,*/*;q=0.8',
    'sec-fetch-site': 'same-site',
    'sec-fetch-mode': 'no-cors',
    'sec-fetch-user': '?1',
    'sec-fetch-dest': 'image',
    'referer': 'https://a1.alicdn.com/',
    'accept-language': 'zh-CN,zh;q=0.9',
    'Referer': 'https://a1.alicdn.com/',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36',
    'Origin': 'https://cart.taobao.com',
    'Pragma': 'no-cache',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Sec-WebSocket-Key': 'pgWIzG+W79r6suOOQTMNQQ==',
    'Upgrade': 'websocket',
    'Sec-WebSocket-Extensions': 'permessage-deflate; client_max_window_bits',
    'Cache-Control': 'no-cache',
    'Connection': 'Upgrade',
    'Sec-WebSocket-Version': '13',
    'if-none-match': 'W/"1efe-gibOP5kr+x7GzP3kayA6Wzcii4g"',
    'if-modified-since': 'Wed, 18 Jan 2017 08:06:30 GMT',
    'pragma': 'no-cache',
    'content-type': 'text/plain',
    'origin': 'https://cart.taobao.com',
}

with open('D://SampleSprider/taobao_cookies.txt','r') as file:
    cookies=eval(file.read())

class click_jiesuan(object):
    def __call__(self,driver):
        try:
            if driver.title.__contains__('确认订单'):
                return True
            else:
                span_jiesuan.click()
                return False
        except BaseException:
            return False

class enter_mima(object):
    def __call__(self,driver):
        try:
            span_mima=driver.find_element_by_xpath('//*[@id="payPassword_container"]/div/span')
            return span_mima
        except BaseException:
            return False


if __name__=='__main__':
    options=webdriver.ChromeOptions()
    for header in headers:
        options.add_argument('{}="{}"'.format(header,headers[header]))
    driver=webdriver.Chrome('D://谷歌驱动/chromedriver.exe')
    driver.maximize_window()
    driver.get('https://cart.taobao.com/cart.htm?spm=a1z02.1.1997525049.1.U6BJfg&from=mini&ad_id=&am_id=&cm_id=&pm_id=1501036000a02c5c3739')

    for cookie in cookies:
        driver.add_cookie(cookie)

    #driver.refresh()
    driver.get('https://cart.taobao.com/cart.htm?spm=a1z02.1.1997525049.1.U6BJfg&from=mini&ad_id=&am_id=&cm_id=&pm_id=1501036000a02c5c3739')

    # 全选按钮
    label_all_select=driver.find_element_by_xpath('//*[@id="J_SelectAll1"]/div/label')
    label_all_select.click()

    # 结算按钮
    span_jiesuan=driver.find_element_by_xpath('//*[@id="J_Go"]/span')
    WebDriverWait(driver,20).until(click_jiesuan())

    # 提交订单按钮
    a_tijiao=driver.find_element_by_xpath('//*[@id="submitOrderPC_1"]/div/a[2]')
    a_tijiao.click()

    # 默认选择支付宝
    # 输入支付宝密码
    span_mima=WebDriverWait(driver,20).until(enter_mima())

    ActionChains(driver).move_to_element(span_mima).click().send_keys(Paypal[0]).perform()

    # 确认付款
    input_fukuan=driver.find_element_by_xpath('//*[@id="J_authSubmit"]')
    input_fukuan.click()


# coding=utf-8
# 使用selenium实现免密登录贴吧，并获取html 2021-04-15
from selenium import webdriver
from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
import time
from selenium.webdriver.support.ui import WebDriverWait

desired_capabilities = DesiredCapabilities.CHROME
desired_capabilities['pageLoadStrategy']='none'

class page_source_exisits(object):
    def __call__(self,driver):
        try:
            return driver.page_source
        except BaseException:
            return False

class add_cookies(object):
    def __call__(self,driver):
        try:
            for cookie in selenium_cookies:
                driver.add_cookie(cookie)
            return True
        except BaseException:
            return False

if __name__=='__main__':
    headers={
        'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
        'Accept-Encoding':'gzip, deflate, br',
        'Accept-Language':'zh-CN,zh;q=0.9',
        'Cache-Control':'max-age=0',
        'Connection':'keep-alive',
        'Host':'tieba.baidu.com',
        'Upgrade-Insecure-Requests':'1',
        'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36'
    }

    option=webdriver.ChromeOptions()
    for header in headers.items():
        option.add_argument('{}="{}"'.format(header.__getitem__(0),header.__getitem__(1)))

    driver=webdriver.Chrome('D://谷歌驱动/chromedriver.exe',options=option)

    driver.get('https://tieba.baidu.com/')


    selenium_cookies=[
        {'domain': '.tieba.baidu.com', 'expiry': 1621043898, 'httpOnly': True, 'name': 'STOKEN', 'path': '/', 'secure': False, 'value': '4dd187b74496abb206bcadec7b194361e316aec330f6d0f9ed2f026a5c4419a6'},
        {'domain': '.baidu.com', 'expiry': 1877651897, 'httpOnly': True, 'name': 'BDUSS_BFESS', 'path': '/', 'sameSite': 'None', 'secure': True, 'value': 'MySjBDUGRmTX5oWlZxOTJzS0pTZDNNY1pwcUdaeTNlYkhIVGJyN0dKNjVLcDlnRVFBQUFBJCQAAAAAAAAAAAEAAADrkk43tfG~zMLWwKowAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALmdd2C5nXdgND'},
        {'domain': '.tieba.baidu.com', 'httpOnly': False, 'name': 'Hm_lpvt_98b9d8c2fd6608d564bf2ac2ae642948', 'path': '/', 'secure': False, 'value': '1618451888'},
        {'domain': '.tieba.baidu.com', 'expiry': 1649987887, 'httpOnly': False, 'name': 'Hm_lvt_98b9d8c2fd6608d564bf2ac2ae642948', 'path': '/', 'secure': False, 'value': '1618451888'},
        {'domain': '.baidu.com', 'expiry': 1877651897, 'httpOnly': True, 'name': 'BDUSS', 'path': '/', 'secure': False, 'value': 'MySjBDUGRmTX5oWlZxOTJzS0pTZDNNY1pwcUdaeTNlYkhIVGJyN0dKNjVLcDlnRVFBQUFBJCQAAAAAAAAAAAEAAADrkk43tfG~zMLWwKowAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALmdd2C5nXdgND'},
        {'domain': '.baidu.com', 'expiry': 1649987886, 'httpOnly': False, 'name': 'BAIDUID_BFESS', 'path': '/', 'sameSite': 'None', 'secure': True, 'value': 'B58886C02FFA16885AC661DCD59D8B38:FG=1'},
        {'domain': '.baidu.com', 'expiry': 1649987886, 'httpOnly': False, 'name': 'BAIDUID', 'path': '/', 'secure': False, 'value': 'B58886C02FFA16885AC661DCD59D8B38:FG=1'}
    ]

    # time.sleep(10)
    # try:
    #     for cookie in selenium_cookies:
    #         driver.add_cookie(cookie)
    # except BaseException:
    #     time.sleep(10)
    #     for cookie in selenium_cookies:
    #         driver.add_cookie(cookie)

    WebDriverWait(driver,20).until(add_cookies())

    driver.refresh()

    page_source=WebDriverWait(driver,20).until(page_source_exisits())
    print(page_source)

    driver.quit()


# coding=utf-8
# 先用selenium模拟登录淘宝网，拿到cookies 2021-04-16
# 将cookies保存在本地文件中 2021-04-22
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import time
import os
from sampleSprider.Common.Info import Taobao
headers = {
    'authority': 'gma.alicdn.com',
    'cache-control': 'no-cache',
    'sec-ch-ua': '"Google Chrome";v="89", "Chromium";v="89", ";Not A Brand";v="99"',
    'sec-ch-ua-mobile': '?0',
    'upgrade-insecure-requests': '1',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36',
    'accept': 'image/avif,image/webp,image/apng,image/svg+xml,image/*,*/*;q=0.8',
    'sec-fetch-site': 'same-site',
    'sec-fetch-mode': 'no-cors',
    'sec-fetch-user': '?1',
    'sec-fetch-dest': 'image',
    'referer': 'https://a1.alicdn.com/',
    'accept-language': 'zh-CN,zh;q=0.9',
    'Referer': 'https://a1.alicdn.com/',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36',
    'Origin': 'https://cart.taobao.com',
    'Pragma': 'no-cache',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Sec-WebSocket-Key': 'pgWIzG+W79r6suOOQTMNQQ==',
    'Upgrade': 'websocket',
    'Sec-WebSocket-Extensions': 'permessage-deflate; client_max_window_bits',
    'Cache-Control': 'no-cache',
    'Connection': 'Upgrade',
    'Sec-WebSocket-Version': '13',
    'if-none-match': 'W/"1efe-gibOP5kr+x7GzP3kayA6Wzcii4g"',
    'if-modified-since': 'Wed, 18 Jan 2017 08:06:30 GMT',
    'pragma': 'no-cache',
    'content-type': 'text/plain',
    'origin': 'https://cart.taobao.com',
}


if __name__=='__main__':
    options=webdriver.ChromeOptions()
    for header in headers:
        options.add_argument('{}="{}"'.format(header,headers[header]))
    driver=webdriver.Chrome('D://谷歌驱动/chromedriver.exe')
    driver.get('https://cart.taobao.com/cart.htm?spm=a1z02.1.1997525049.1.U6BJfg&from=mini&ad_id=&am_id=&cm_id=&pm_id=1501036000a02c5c3739')

    username=driver.find_element_by_xpath('//*[@id="fm-login-id"]')
    username.send_keys(Taobao[0])
    password=driver.find_element_by_xpath('//*[@id="fm-login-password"]')
    password.send_keys(Taobao[1])
    password.send_keys(Keys.RETURN)

    time.sleep(5)
    print(driver.get_cookies())

    path='D://SampleSprider/'
    os.makedirs(path,exist_ok=True)
    with open(path+'taobao_cookies.txt','w') as file:
        file.write(driver.get_cookies().__str__())



# coding=utf-8
# 用request方式实现免密登录 2021-04-15

from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
import requests

desired_capabilities = DesiredCapabilities.CHROME
desired_capabilities['pageLoadStrategy']='none'
if __name__=='__main__':
    headers={
        'Accept':'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
        'Accept-Encoding':'gzip, deflate, br',
        'Accept-Language':'zh-CN,zh;q=0.9',
        'Cache-Control':'max-age=0',
        'Connection':'keep-alive',
        'Host':'tieba.baidu.com',
        'Upgrade-Insecure-Requests':'1',
        'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36'
    }
    selenium_cookies=[
        {'domain': '.tieba.baidu.com', 'expiry': 1621043898, 'httpOnly': True, 'name': 'STOKEN', 'path': '/', 'secure': False, 'value': '4dd187b74496abb206bcadec7b194361e316aec330f6d0f9ed2f026a5c4419a6'},
        {'domain': '.baidu.com', 'expiry': 1877651897, 'httpOnly': True, 'name': 'BDUSS_BFESS', 'path': '/', 'sameSite': 'None', 'secure': True, 'value': 'MySjBDUGRmTX5oWlZxOTJzS0pTZDNNY1pwcUdaeTNlYkhIVGJyN0dKNjVLcDlnRVFBQUFBJCQAAAAAAAAAAAEAAADrkk43tfG~zMLWwKowAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALmdd2C5nXdgND'},
        {'domain': '.tieba.baidu.com', 'httpOnly': False, 'name': 'Hm_lpvt_98b9d8c2fd6608d564bf2ac2ae642948', 'path': '/', 'secure': False, 'value': '1618451888'},
        {'domain': '.tieba.baidu.com', 'expiry': 1649987887, 'httpOnly': False, 'name': 'Hm_lvt_98b9d8c2fd6608d564bf2ac2ae642948', 'path': '/', 'secure': False, 'value': '1618451888'},
        {'domain': '.baidu.com', 'expiry': 1877651897, 'httpOnly': True, 'name': 'BDUSS', 'path': '/', 'secure': False, 'value': 'MySjBDUGRmTX5oWlZxOTJzS0pTZDNNY1pwcUdaeTNlYkhIVGJyN0dKNjVLcDlnRVFBQUFBJCQAAAAAAAAAAAEAAADrkk43tfG~zMLWwKowAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALmdd2C5nXdgND'},
        {'domain': '.baidu.com', 'expiry': 1649987886, 'httpOnly': False, 'name': 'BAIDUID_BFESS', 'path': '/', 'sameSite': 'None', 'secure': True, 'value': 'B58886C02FFA16885AC661DCD59D8B38:FG=1'},
        {'domain': '.baidu.com', 'expiry': 1649987886, 'httpOnly': False, 'name': 'BAIDUID', 'path': '/', 'secure': False, 'value': 'B58886C02FFA16885AC661DCD59D8B38:FG=1'}
    ]

    requests_cookies={}
    for cookie in selenium_cookies:
        requests_cookies[cookie['name']] = cookie['value']

    r= requests.get('https://tieba.baidu.com/', headers=headers, cookies=requests_cookies)
    print(r.text)



# coding=utf-8
# 尝试用requests获取到购物车列表，但是动态加载很烦,先不使用requests 2021-04-16
import requests

headers = {
    'authority': 'gma.alicdn.com',
    'cache-control': 'no-cache',
    'sec-ch-ua': '"Google Chrome";v="89", "Chromium";v="89", ";Not A Brand";v="99"',
    'sec-ch-ua-mobile': '?0',
    'upgrade-insecure-requests': '1',
    'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36',
    'accept': 'image/avif,image/webp,image/apng,image/svg+xml,image/*,*/*;q=0.8',
    'sec-fetch-site': 'same-site',
    'sec-fetch-mode': 'no-cors',
    'sec-fetch-user': '?1',
    'sec-fetch-dest': 'image',
    'referer': 'https://a1.alicdn.com/',
    'accept-language': 'zh-CN,zh;q=0.9',
    'cookie': 't=9c4249a362a7567ff54490700617c0ca; xlly_s=1; thw=cn; cna=6UT8GGIdq0kCAXBAg2VSYHgZ; _samesite_flag_=true; cookie2=122c59e0073722ea70a887147a096ecf; _tb_token_=e3e38836d5bed; sgcookie=E100w%2B5heYpvWGMB796FZfaQ1JbuW9T2bwr9lYtEs5rMXbhInSCD2j7MY8O77ARl%2Fboz%2Bvfxh1wXIo1O3FD1UTA13A%3D%3D; unb=4286722913; uc3=lg2=UtASsssmOIJ0bQ%3D%3D&vt3=F8dCuwpnl0yrc4%2BJGyg%3D&nk2=F5RCYRiZq7FIMF0%3D&id2=Vy6wuiK%2BS0fkWw%3D%3D; csg=78b48096; lgc=tb743940389; cookie17=Vy6wuiK%2BS0fkWw%3D%3D; dnk=tb743940389; skt=9be306c41f340ccc; existShop=MTYxODU0MTU3OQ%3D%3D; uc4=id4=0%40VXkX0rZulCIxTBcvUj3yarFDqlej&nk4=0%40FY4Jj1fjy134mSEe8CjdnWHfThnusA%3D%3D; tracknick=tb743940389; _cc_=Vq8l%2BKCLiw%3D%3D; _l_g_=Ug%3D%3D; sg=937; _nk_=tb743940389; cookie1=U%2BJ4RwTGBOS7q2WhDFVS1zuEnBDdVCa8rH3wvCldIYk%3D; _m_h5_tk=5517bf0beb5723faa6c7189c7e7ef373_1618550580915; _m_h5_tk_enc=23d58d5205cffe9fde3f09a71de84d5f; mt=ci=4_1; uc1=cookie14=Uoe1iuWW1lLyNg%3D%3D&existShop=false&cookie16=V32FPkk%2FxXMk5UvIbNtImtMfJQ%3D%3D&cart_m=0&cookie15=UIHiLt3xD8xYTw%3D%3D&cookie21=W5iHLLyFe3xm&pas=0; l=eBgznlKcjwXjEw8vBOfwnurza77tsIRAguPzaNbMiOCPO4CH5etFW6a_WaLMCnGVh6JWR3yIziz8BeYBqC22sWRdUKaOYMkmn; tfstk=ckoRB2gS7IAl1t2xQ4LcdOA2k8vGZ5OLGTNhvLL9WhgOfAIdiBiiXVaMPJ18DKC..; isg=BG1tOleM8bWal5XWuQQRMus4fAnnyqGcC5WUE69yrIRxJo3Ydxh9bAn4EPrAprlU',
    'Referer': 'https://a1.alicdn.com/',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36',
    'Origin': 'https://cart.taobao.com',
    'Pragma': 'no-cache',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Sec-WebSocket-Key': 'pgWIzG+W79r6suOOQTMNQQ==',
    'Upgrade': 'websocket',
    'Sec-WebSocket-Extensions': 'permessage-deflate; client_max_window_bits',
    'Cache-Control': 'no-cache',
    'Connection': 'Upgrade',
    'Sec-WebSocket-Version': '13',
    'if-none-match': 'W/"1efe-gibOP5kr+x7GzP3kayA6Wzcii4g"',
    'if-modified-since': 'Wed, 18 Jan 2017 08:06:30 GMT',
    'pragma': 'no-cache',
    'content-type': 'text/plain',
    'origin': 'https://cart.taobao.com',
}

params = (
    ('spm', 'a1z02.1.1997525049.1.U6BJfg'),
    ('from', 'mini'),
    ('ad_id', ''),
    ('am_id', ''),
    ('cm_id', ''),
    ('pm_id', '1501036000a02c5c3739'),
)

data = [
    ('{}', ''),
    ('{}', ''),
    ('data', '{"pageSize":20,"endTime":1618542900510}'),
]


if __name__=='__main__':
    response = requests.post('https://cart.taobao.com/cart.htm', headers=headers, params=params, data=data)

    print(response.text)



# coding=utf-8
# 简单爬取小说网站资源 2021-03-31
# 1.先下载读取工具urllib(内置，无需下载)和requests（第三方库）   pip install requests
# 2.下载解析工具 Beautiful Soup和lxml   pip install beautifulsoup4|pip install lxml
# 3.学习四大对象 2021-03-31，2021-04-07
import requests
from bs4 import BeautifulSoup

if __name__=='__main__':
    r= requests.get('https://www.vbiquge.com/15_15338/8549128.html')
    r.encoding='utf-8'
    str_html=r.text
#     str_html=html = """
# <html>
# <head>
# <title>Jack_Cui</title>
# </head>
# <body>
# <p class="title" name="blog"><b>My Blog</b></p>
# <li><!--注释--></li>
# <a href="http://blog.csdn.net/c406495762/article/details/58716886" class="sister" id="link1">Python3网络爬虫(一)：利用urllib进行简单的网页抓取</a><br/>
# <a href="http://blog.csdn.net/c406495762/article/details/59095864" class="sister" id="link2">Python3网络爬虫(二)：利用urllib.urlopen发送数据</a><br/>
# <a href="http://blog.csdn.net/c406495762/article/details/59488464" class="sister" id="link3">Python3网络爬虫(三)：urllib.error异常</a><br/>
# </body>
# </html>
# """

    # 建议给定解析器类型 "lxml","lxml-xml", "html.parser", "html5lib"或者"html", "html5", "xml"
    soup=BeautifulSoup(str_html,'lxml')

    # 美化输出
    # print(soup.prettify())

# 1.Tag 对应标签 获取相应标签，不过只能获取第一个匹配到的标签
    # print(type(soup.title))  #<class 'bs4.element.Tag'>
    # print(soup.title)
    # print(soup.head)
    # print(soup.head.title)
    # print(soup.a)

    # Tag类有两个属性，name和attrs, name返回标签名;attrs返回该标签所有属性的字典
    # print(type(soup.title.name))  # <class 'str'>
    # print(type(soup.title.attrs)) # <class 'dict'>
    # print(soup.title.name)
    # print(soup.title.attrs)

    # print(soup.meta)
    # print(soup.meta.name)
    # print(soup.meta.attrs)

# 2.NavigableString  获取标签的值
    # print(type(soup.title.string))  # <class 'bs4.element.NavigableString'>
    # print(soup.title.string)

# 3.BeautifulSoup  代表一整个文档 可以视作特殊的Tag, 其也有name和attrs属性
    # print(type(soup))   # <class 'bs4.BeautifulSoup'>
    # print(soup.name)    # [document]
    # print(soup.attrs)   # {}

# 4.Comment 一个特殊的Navigable String类型 代表标签中的值为注释 当.string输出时，会自动去掉注释，所以有时需要手动处理
    # print(type(soup.li))     # <class 'bs4.element.Tag'>
    # print(soup.li)           # <li><!--注释--></li>
    # print(type(soup.li.string))  # <class 'bs4.element.Comment'>
    # print(soup.li.string)    # 注释
    # if type(soup.li.string).__name__=='Comment':
    #     print("<!--{}-->".format(soup.li.string))




# coding=utf-8
# 从新笔趣阁爬取诡秘之主小说的所有章节 并下载到本地txt文件 2021-04-07
# 从新笔趣阁爬取任意一本小说的所有章节 优化 2021-04-09
# 解决编码不一致导致的错误 2021-04-13

from bs4 import BeautifulSoup
import requests
import sys

# 该程序设置了运行参数,主程序不再改动，从数组第二个参数开始设置，分别为书本章节目录地址 小说名字
sys.argv =[sys.argv[0],'https://www.vbiquge.com/76_76449/','万界天尊']

def getOneChapter(url):
    try:
        r= requests.get(url)
    except BaseException:
        getOneChapter(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')
    tag_div_contents=soup.body.find_all(attrs={'id':'content'})[0]
    return tag_div_contents.text.replace('    ','\n')#.replace('\xa0','')

if __name__ == '__main__':
    path='D://'+sys.argv[2]+'.txt'
    # 文件默认的是gkb编码，而页面编码是utf-8，所以会产生部分字符转换异常的情况，需统一
    file=open(path,'w',encoding='utf-8')
    pre_url='https://www.vbiquge.com'
    # 目录地址
    url=sys.argv[1]
    r= requests.get(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')

    tag_div_box_con=soup.find_all('div',attrs={'id':'list'})[0]
    # 顺利找到目录所在标签对
    tag_dd_chapters=tag_div_box_con.find_all('dd')
    try:
        for tag_dd_chapter in tag_dd_chapters:
            # 小说章节题目
            str_title=tag_dd_chapter.string
            # 小说各章节地址
            url_chapter=tag_dd_chapter.a.attrs['href']
            url=pre_url+url_chapter

            print(str_title,end='')
            file.write(str_title+'\n')
            file.write(getOneChapter(url))
            file.write('\n-------------------------------------------------------------------------------------------------------------\n')
            print('\t'+'下载完成')
    finally:
        file.close()


# coding=utf-8
# 爬取动漫之家漫画网 （动态加载） 2021-04-07
# 编码 改进 2021-04-08

from bs4 import BeautifulSoup
import requests
import re
from urllib.request import urlretrieve
import os
import sys

# 该程序设置了运行参数,主程序不再改动，从数组第二个参数开始设置，分别为漫画章节目录地址 漫画名字
sys.argv =[sys.argv[0],'https://www.dmzj.com/info/yaoshenji.html','妖神记']

# 爬取一章的漫画图片
def getOneChapter(url,chapterName):
    r= requests.get(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')
    # 该页面采取动态加载，反爬手段之一，图片地址散落在script里，，用正则找出三段url
    str_script_oneChapter=soup.find_all('script',attrs={'type':'text/javascript'})[0].string
    str_first_url=re.findall('\|+(\d{4})\|+',str_script_oneChapter)[0]
    str_second_url=re.findall('\|(\d{5})\|',str_script_oneChapter)[0]
    str_third_urls=re.findall('(\d{13,14})\|',str_script_oneChapter)
    # 我们这时已经得到 所有图片连接的地址 ，但是是乱序的，需要排一下序
    str_third_urls.sort()

    # 用作图片的名称使用，因为现在单张图片没有名字
    pic_name=1
    for str_third_url in str_third_urls:
        url_pic='https://images.dmzj1.com/img/chapterpic/'+str_first_url+'/'+str_second_url+'/'+str_third_url+'.jpg'
        downloadPic(url_pic,chapterName,pic_name)
        pic_name=pic_name+1

# 下载该url下的图片
def downloadPic(url_pic,chapterName,pic_name):
    # 因为windows下有一些特殊字符不能作为目录名，所以需剔除
    chapterName=re.sub('[.|\\|/|:|*|?|"|<|>|\|]','',chapterName)
    path='D://{}/{}'.format(sys.argv[2],chapterName)
    # 因为不能写入未创建的目录，所以需要先创建目录
    mkdir(path)
    # 防止连接断开，进行重连操作
    try:
        urlretrieve(url_pic,path+'/{}.jpg'.format(pic_name))
    except BaseException:
        print(chapterName+'\t'+'连接失败，正在重新连接。。。。')
        downloadPic(url_pic,chapterName,pic_name)

# 创建目录
def mkdir(path):
    if not os.path.exists(path):
        os.makedirs(path.encode('utf-8'))

if __name__=='__main__':
    #目录地址
    url=sys.argv[1]
    r= requests.get(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')

    tag_ul_allChapters=soup.find_all('ul',attrs={'class':'list_con_li autoHeight'})[1]
    tag_a_allChapters=tag_ul_allChapters.find_all('a')
    # 目前一切顺利 已经找到每一章节 的地址和名称 标签对
    for tag_a_allChapter in tag_a_allChapters:
        # 章节url
        str_url_chapter=tag_a_allChapter.attrs['href']
        # 章节名称
        str_title_chapter=tag_a_allChapter.find_all('span',attrs={'class':'list_con_zj'})[0].text
        getOneChapter(str_url_chapter,str_title_chapter)
        print(str_title_chapter+'\t'+'下载完成。')


# coding=utf-8
# 学习遍历、查找结点 2021-04-07
import requests
from bs4 import BeautifulSoup

if __name__ == '__main__':
    r= requests.get('https://www.vbiquge.com/15_15338/8549128.html')
    r.encoding='utf-8'
    str_html=r.text
    soup=BeautifulSoup(str_html,'lxml')

    div=soup.body.div
    # print(soup.prettify())

# 1.contents 将直接子节点以List[Tag]形式返回 需注意偶数(或奇数)下标值为'\n'
    # print(soup.body.contents)
    # print(soup.body.div.contents)
    # print(soup.body.script.contents)
    # print(type(div.contents[1]))  # <class 'bs4.element.Tag'>
    # print(div.contents[1])
    # print(div.contents[3])
    # print(div.contents[5])

    # for i in soup.body.div.contents:
    #     print(i)

# 2.find_all()  find_all(name, attrs, recursive, text, limit, **kwargs)：
    # (1) name:返回所有相应name标签的List[Tag]
    # 给定字符串
    # print(div.find_all('div'))
    # print(div.find_all('li'))

    # 给定正则表达式
    # print(div.find_all(re.compile('a|li')))
    # print(div.find_all(re.compile('\wi\w\d*')))

    # 传递列表
    # print(div.find_all(['h1','li']))

    # (2) attrs:定义一个字典，返回包含该属性的Tag列表
    # print(div.find_all(attrs={'class':'header'}))

    # (3) recursive 默认为True,会对soup的所有子节点进行查找，若设置为False，则只会查找直接子节点
    # print(div.find_all('script'))
    # print(div.find_all('script',recursive=False))

    # (4) text 给定值内容，可以是字符串，正则，列表 只返回标签值，无标签对
    # print(div.find_all(text='新笔趣阁'))
    # print(div.find_all(text=re.compile('[\u4e00-\u9fa5]*一章'))) # [\u4e00-\u9fa5]是简体中文utf-8的范围
    # print(div.find_all(text=['新笔趣阁','永久书架']))

    # (5) limit 限制返回个数
    # print(div.find_all('li'))
    # print(div.find_all('li',limit=2))


# coding=utf-8
# 发现只能用于爬取一本漫画，在获取正则过程中有问题，更改代码，直接手撸JavaScript 2021-04-09
# 成功明白获取图片链接的规则，但是分为两种情况：一章只有一张图片;一章有多张图片，甚至字符串数组超过36. 2021-04-12
# 我去 有些漫画部分章节链接 本身就连不通 2021-04-12
# 存在章节数靠后的章节连接失败的情况，日后改进吧 2021-04-13

from bs4 import BeautifulSoup
import requests
import re
from urllib.request import urlretrieve
import os
import sys
import logging

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
log = logging.getLogger(__name__)


# 该程序设置了运行参数,主程序不再改动，从数组第二个参数开始设置，分别为漫画章节目录地址 漫画名字
# sys.argv =[sys.argv[0],'https://www.dmzj.com/info/dengpaozhixin2.html','灯泡之心']
sys.argv =[sys.argv[0],'https://www.dmzj.com/info/yaoshenji.html','妖神记']
# sys.argv =[sys.argv[0],'https://www.dmzj.com/info/aaguziyaoruxuejuedouxueyuandeyangzi.html','【AA】咕哒子要入学决斗学院的样子']

# 爬取一章的漫画图片
def getOneChapter(url,chapterName):
    r= requests.get(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')
    # 该页面采取动态加载，反爬手段之一，图片地址散落在script里，，用正则找出三段url
    list_script_oneChapter=soup.find_all('script',attrs={'type':'text/javascript'})
    # 部分章节资源出错
    if list_script_oneChapter.__len__()==0:
        log.error('{} 链接出错'.format(chapterName))
        return ;
    else:
        str_script_oneChapter=list_script_oneChapter[0].string

    tuple_oneChapter=re.findall("return p}.*{(.*)}.*',(\d+),(\d+),'(.*)'\.split",str_script_oneChapter)[0]

    list_rules=tuple_oneChapter[0].split(',')[2].split(':')[1].strip('"').split('\\\\/')
    radix=tuple_oneChapter[1]
    len=tuple_oneChapter[2]
    list_part_url=tuple_oneChapter[3].split('|')

    url_pic='https://images.dmzj1.com/'
    # 用作图片的名称使用，因为现在单张图片没有名字
    pic_name=1
    for list_rule in list_rules:
        if '.' in list_rule:
            list_finally_url=list_rule.split('\\\\')[0].split('.')
            url_pic+=list_part_url[sixtyTwoToDecimal(list_finally_url[0])]+'.'+list_part_url[sixtyTwoToDecimal(list_finally_url[1])]
            downloadPic(url_pic,chapterName,pic_name)
            pic_name+=1
            url_pic='https://images.dmzj1.com/img/'
        else:
            url_pic=url_pic+list_part_url[sixtyTwoToDecimal(list_rule)]+'/'

# 下载该url下的图片
def downloadPic(url_pic,chapterName,pic_name):
    # 因为windows下有一些特殊字符不能作为目录名，所以需剔除
    chapterName=re.sub('[.|\\|/|:|*|?|"|<|>|\|]','',chapterName)
    path='D://{}/{}'.format(sys.argv[2],chapterName)
    # 因为不能写入未创建的目录，所以需要先创建目录
    mkdir(path)
    # 防止连接断开，进行重连操作
    try:
        urlretrieve(url_pic,path+'/{}.jpg'.format(pic_name))
    except BaseException:
        log.error(chapterName+'\t'+url_pic+'连接失败，正在重新连接。。。。')
        downloadPic(url_pic,chapterName,pic_name)

# 创建目录
def mkdir(path):
    if not os.path.exists(path):
        os.makedirs(path.encode('utf-8'))

# 六十二进制 转 十进制
def sixtyTwoToDecimal(n):
    n_len=len(n)
    if n_len==1:
        return oneCharToInt(n)

    res=0
    for i in range(0,n_len):
        res+=pow(62,n_len-1-i)*oneCharToInt(n[i:i+1])
    return res

# 一个字符 六十二进制 转 十进制
def oneCharToInt(n):
    ascii_n=ord(n)
    if ascii_n>=48 and ascii_n<=57:
        return ascii_n-48
    elif ascii_n>=97 and ascii_n<=122:
        return ascii_n-87
    elif ascii_n>=65 and ascii_n<=90:
        return ascii_n-29


if __name__=='__main__':
    #目录地址
    url=sys.argv[1]
    r= requests.get(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')

    tag_ul_allChapters=soup.find_all('ul',attrs={'class':'list_con_li autoHeight'})[1]
    tag_a_allChapters=tag_ul_allChapters.find_all('a')
    # 目前一切顺利 已经找到每一章节 的地址和名称 标签对
    for tag_a_allChapter in tag_a_allChapters:
        # 章节url
        str_url_chapter=tag_a_allChapter.attrs['href']
        # 章节名称
        str_title_chapter=tag_a_allChapter.find_all('span',attrs={'class':'list_con_zj'})[0].text
        getOneChapter(str_url_chapter,str_title_chapter)
        log.info(str_title_chapter+'\t'+'下载完成。')


# coding=utf-8
# 调用旷视的官方美颜api 2021-04-04
# pip install requests
import base64
import requests
import json
import sys

import logging

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
log = logging.getLogger(__name__)


sys.argv =[sys.argv[0],'C://Users/zhangfan36/Desktop/简历/证件照.jpg']
if __name__=='__main__':
    # 准备好必要参数
    beautiful_url='https://api-cn.faceplusplus.com/facepp/v2/beautify'
    api_key='kTseH9TtSH_Hody8k15fhkRzyXpEuhmJ'
    api_secret='9kNy0Utc-mIDTtnvwVWuzHv3uQgIdscZ'
    with open(sys.argv[1],'rb') as f:
        image_base64=base64.b64encode(f.read())

    data={
        'api_key':api_key,
        'api_secret':api_secret,
        'image_base64':image_base64,
        'whitening':50, #美白
        'smoothing':50, #磨皮
        'thinface':50, #瘦脸
        'shrink_face':50, #小脸
        'enlarge_eye':50, #大眼
        'remove_eyebrow':50, #去眉毛
        #'filter_type':     #滤镜
    }

    r= requests.post(beautiful_url, data=data)
    html=json.loads(r.text)

    result=html['result']
    img_data=base64.b64decode(result)
    with open('D://证件照.jpg','wb') as f:
        f.write(img_data)
        log.info('文件生成完毕')



# coding=utf-8
# 从ok资源网下载视频，可惜的是 该网站的资源已失效 下载找到资源网再下载 2021-04-13

import requests
from bs4 import BeautifulSoup
import logging
import sys

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
log = logging.getLogger(__name__)

sys.argv =[sys.argv[0],'越狱第一季']

search_name=sys.argv[1]
search_url='http://haozy.cc/index.php'
search_parameters={
    'm':'vod-search'
}
search_headers={
    'User-Agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.114 Safari/537.36',
    'Referer':'http://haozy.cc/',
    'Origin':'http://haozy.cc',
    'Host':'haozy.cc'
}
search_data={
    'wd':search_name,
    'submit':'search'
}

def downloadAllVideo(url):
    r= requests.get(url)
    r.encoding='utf-8'
    soup=BeautifulSoup(r.text,'lxml')
    print(soup.prettify())


if __name__=='__main__':
    r= requests.post(search_url, params=search_parameters, headers=search_headers, data=search_data)
    r.encoding='utf-8'

    soup=BeautifulSoup(r.text,'lxml')
    list_span_video=soup.find_all('span',class_='xing_vb4')
    if list_span_video.__len__()==0:
        log.error("未找到该资源")
    else:
        str_href_video=list_span_video[0].find_all('a')[0].attrs['href']
        downloadAllVideo(search_url+str_href_video)



#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='zf_sampleSprider',
    version='0.1.0',
    author='zhangfan',
    author_email='1054934500@qq.com',
    url='https://github.com/ilovepythonJAVAc/test2020_8_4',
    description='简易爬虫',
    packages=['sampleSprider','sampleSprider.Common'],
    install_requires=[],
    entry_points={
        'console_scripts': [
            'fiction=sampleSprider.SampleSprider3_Fiction:main',
            'comics=sampleSprider.SampleSprider4_Comics1:main'
        ]
    }
)


# coding=utf-8
# 初步学习python爬虫 先学习requests模块 2021-03-22
import requests

if __name__=="__main__":
    url1="https://www.baidu.com"
    url2="https://tieba.baidu.com/f"
    # # 谷歌浏览器用户代理
    headers={'user-agent':'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.90 Safari/537.36'}
    # # iphone Safari浏览器代理
    # headers1={'user-agent':'Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_0 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8A293 Safari/6531.22.7'}
    #
    #
    # r1=requests.get(url1,headers=headers1)
    # print(r1.status_code)
    # r1.encoding="UTF-8"
    # print(r1.text)
    # print(r1.headers['content-type'])
    # print(r1.encoding)

    # r2=requests.get(url2,params={"kw":"赛博朋克2077"})
    # print(r2.status_code)
    # print(r2.text)
    # print(r2.url)


    # r2=requests.head(url1)
    # print(r2.text)
    # print(r2.status_code)
    # print(r2.headers['content-type'])
    # print(r2.encoding)

    # r3=requests.post(url1)
    # print(r3.status_code)
    # print(r3.text)
    # print(r3.encoding)

    # r4=requests.options(url1)
    # print(r4.status_code)
    # print(r4.text)
    # print(r4.url)

    # r = requests.get('https://api.github.com/events/404')
    # print(r.status_code)
    # print(r.raise_for_status())
    # print(r.text)
    # print(r.json())
    # print(r.content)

    url3="https://httpbin.org/post"
    url4="https://httpbin.org/get"
    # r=requests.post(url3,json={'key1':'value1','key2':'value2'},headers=headers)
    # print(r.text)

    # r=requests.post(url3,data={'key1':'value1','key2':'value2'})
    # print(r.text)

    # r=requests.get(url4)
    # print(r.text)
    # print(r.headers)

    url5 = 'http://dp.58corp.com/data-develop/task-list'
    url6='https://httpbin.org/cookies'

    cookies=dict(Cookie="wmda_uuid=7e9f46c2f9586cebac861571355b237d; wmda_new_uuid=1; wmda_visited_projects=%3B12590408761269; DP_SESSION_ID=74b789b3-5a3a-49ab-9346-0b61e754e742; SSO_SESSION_ID=ST-3722946-3HolqHNvdxt00mEoOgNG-passport-58corp-com; wmda_session_id_12590408761269=1616485499262-abc8b58f-de86-23de")
    cookies1=dict(cookies_are='working')


    r= requests.get(url5, headers=headers)
    print(r.status_code)
    print(r.text)

    # s=requests.session()
    # r=s.get(url1,headers=headers)
    # print(r.text)
    # print(r.cookies)



# coding=utf-8
# 学习selenium 2021-04-15
# 获取百度贴吧的cookie，便于使用cookie免密登录 2021-04-15
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import time
from selenium.webdriver.support.ui import Select
from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
from sampleSprider.Common.Info import Tieba

# 设置页面加载策略为 在加载完html后开始执行selenium
desired_capabilities = DesiredCapabilities.CHROME
desired_capabilities["pageLoadStrategy"] = "none"
if __name__=='__main__':
    option=webdriver.ChromeOptions()
    option.add_argument('user-agent="Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36"')

    driver=webdriver.Chrome('D://谷歌驱动/chromedriver.exe',options=option)

    driver.get('https://tieba.baidu.com/')

    time.sleep(6)

    zhmmdl=driver.find_element_by_xpath('//*[@id="TANGRAM__PSP_4__footerULoginBtn"]')
    zhmmdl.click()
    time.sleep(3)

    user_name=driver.find_element_by_xpath('//*[@id="TANGRAM__PSP_4__userName"]')
    user_name.send_keys(Tieba[0])
    password=driver.find_element_by_xpath('//*[@id="TANGRAM__PSP_4__password"]')
    password.send_keys(Tieba[1])
    dl=driver.find_element_by_xpath('//*[@id="TANGRAM__PSP_4__submit"]')
    dl.click()

    time.sleep(5)
    cookies=driver.get_cookies()
    print(cookies)
    # select=driver.find_element_by_xpath('//*[@id="plc_frame"]/div[2]/div[2]/p[1]/select')
    # options=select.find_elements_by_tag_name('option')
    # for option in options:
    #     print(option.text)
    #     option.click()

    # 操作select元素
    # select=Select(driver.find_element_by_xpath('//*[@id="plc_frame"]/div[2]/div[2]/p[1]/select'))
    # # select.select_by_index(2)
    # options=select.all_selected_options
    # for option in options:
    #     print(option.text)

    # alert=driver.switch_to.alert
    # print(alert.text)
    # for handle in driver.window_handles:
    #     driver.switch_to.window()

    # 浏览器后退和前进
    # elem=driver.find_element_by_xpath('//*[@id="weibo_top_public"]/div/div/div[2]/input')
    # elem.send_keys('赵立坚')
    # elem.send_keys(Keys.RETURN)
    # time.sleep(2)
    # driver.back()
    # time.sleep(3)
    # driver.forward()